﻿/***********************************************************************************************************/
/* Datei: Internals.cs                                                                                     */
/***********************************************************************************************************/
/* Autor:   Stephan Wienert                                                                                */
/* Datum:   29.12.2015                                                                                     */
/* Beschr.: Statische Klasse für interne Methoden der Assembly                                             */
/* Projekt: ClusterQuant                                                                                   */
/* Lizenz:  Freigegeben unter den Bedingungen der GNU General Public License (GPL)                         */
/***********************************************************************************************************/

using System;
using System.Reflection;

using SharpAccessory.Resources;
using SharpAccessory.Globalization;

using SharpAccessory.ClusterQuant.Resources;


/***********************************************************************************************************/
/********************************** Namespace: SharpAccessory.ClusterQuant *********************************/
/***********************************************************************************************************/

namespace SharpAccessory.ClusterQuant
{
	
	/*******************************************************************************************************/
	/**************************************** Klasse: Internals ********************************************/
	/*******************************************************************************************************/
	
	internal static class Internals
	{
		//*** Konstanten-Deklarationen **********************************************************************
		private const string RESOURCE_PATH="Resources.InternalResources";
		private const string ASSEMBLY_ROOT="#Accessory.ClusterQuant";
		
		//*** Variablen-Deklarationen ***********************************************************************
		private static EmbeddedResourceLoader resources;
		private static LanguagePack strings;
		
		
		/***************************************************************************************************/
		/********************************** Eigenschaft: Strings *******************************************/
		/***************************************************************************************************/
		
		internal static LanguagePack Strings
		{
			get{ return strings; }
		}
		
		
		/***************************************************************************************************/
		/********************************** Eigenschaft: Resources *****************************************/
		/***************************************************************************************************/
		
		internal static EmbeddedResourceLoader Resources
		{
			get{ return resources; }
		}
		
		
		/***************************************************************************************************/
		/************************************** Initialisierung ********************************************/
		/***************************************************************************************************/
		
		static Internals()
		{
			//*** Variablen-Deklarationen *******************************************************************
			Assembly assembly;
			string folder;
			
			//*** Die ausführende Assembly bestimmen ********************************************************
			assembly=Assembly.GetExecutingAssembly();
			
			//*** Den Pfad zu den eingebetteten Ressourcen bestimmen ****************************************
			folder=ASSEMBLY_ROOT+"."+RESOURCE_PATH;
			
			//*** Den ResourceLoader anlegen ****************************************************************
			resources=new EmbeddedResourceLoader(assembly, folder, typeof(InternalResource));
			
			//*** Das Sprach-Paket initialisieren ***********************************************************
			strings=LoadLanguagePack(Accessory.Language);
			
			//*** Den EventHandler zum Aktualisieren des Sprach-Pakets zusammensetzen und registrieren ******
			Accessory.LanguageChanged+=delegate
			{
				strings=LoadLanguagePack(Accessory.Language);
			};
		}
		
		
		/***************************************************************************************************/
		/******************************** Funktion: LoadLanguagePack ***************************************/
		/***************************************************************************************************/
		
		private static LanguagePack LoadLanguagePack(Language language)
		{
			//*** Variablen-Deklarationen *******************************************************************
			byte[] data;
			
			//*** Das entsprechende Sprach-Paket laden ******************************************************
			switch(language)
			{
				//*** Deutsch *******************************************************************************
				case Language.German:
					 data=Resources.Load(InternalResource.German);
					 break;
				//*** Default: Englisch *********************************************************************
				default: data=Resources.Load(InternalResource.English); break;
			}
			
			//*** Ende **************************************************************************************
			return LanguagePack.FromBuffer(data);
		}
	
	}
}

/*****************************************************#*****************************************************/